@@ -13,7 +13,7 @@ from astropy.stats import sigma_clipped_stats
 import numpy as np
 from photutils import DAOStarFinder
 import json
-from muse_psf.utils.paths import paths as path
+from muse_psf.utils import paths as path
 
 #########################################
 ############ Initial Message   ##########
